@@ -1,3 +1,4 @@
+#![allow(incomplete_features)]
 #![feature(iter_intersperse)]
 #![feature(adt_const_params)]
 
@@ -7,7 +8,7 @@ use std::collections::HashMap;
 
 /// Functions that given statements return the statements which compute the respective derivatives.
 pub mod derivatives;
-pub use derivatives::{cumulative_derivative_wrt_rt, Type};
+pub use derivatives::*;
 
 mod dict;
 pub use dict::*;
